# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/predict/mfcc-buffer/mfcc-buffer-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/predict/mfcc-buffer/mfcc-buffer-service.proto',
  package='ai.cogneed.api.predict.mfccbuffer',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n<cogneed-protos/predict/mfcc-buffer/mfcc-buffer-service.proto\x12!ai.cogneed.api.predict.mfccbuffer\"\"\n\x12MfccBufferResponse\x12\x0c\n\x04mfcc\x18\x01 \x01(\x0c\"F\n\x11MfccBufferRequest\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\x32\x8c\x01\n\x11MfccBufferService\x12w\n\x08get_mfcc\x12\x34.ai.cogneed.api.predict.mfccbuffer.MfccBufferRequest\x1a\x35.ai.cogneed.api.predict.mfccbuffer.MfccBufferResponseb\x06proto3')
)




_MFCCBUFFERRESPONSE = _descriptor.Descriptor(
  name='MfccBufferResponse',
  full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mfcc', full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferResponse.mfcc', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=133,
)


_MFCCBUFFERREQUEST = _descriptor.Descriptor(
  name='MfccBufferRequest',
  full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferRequest.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferRequest.index', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferRequest.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=205,
)

DESCRIPTOR.message_types_by_name['MfccBufferResponse'] = _MFCCBUFFERRESPONSE
DESCRIPTOR.message_types_by_name['MfccBufferRequest'] = _MFCCBUFFERREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MfccBufferResponse = _reflection.GeneratedProtocolMessageType('MfccBufferResponse', (_message.Message,), dict(
  DESCRIPTOR = _MFCCBUFFERRESPONSE,
  __module__ = 'cogneed_protos.predict.mfcc_buffer.mfcc_buffer_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.mfccbuffer.MfccBufferResponse)
  ))
_sym_db.RegisterMessage(MfccBufferResponse)

MfccBufferRequest = _reflection.GeneratedProtocolMessageType('MfccBufferRequest', (_message.Message,), dict(
  DESCRIPTOR = _MFCCBUFFERREQUEST,
  __module__ = 'cogneed_protos.predict.mfcc_buffer.mfcc_buffer_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.mfccbuffer.MfccBufferRequest)
  ))
_sym_db.RegisterMessage(MfccBufferRequest)



_MFCCBUFFERSERVICE = _descriptor.ServiceDescriptor(
  name='MfccBufferService',
  full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=208,
  serialized_end=348,
  methods=[
  _descriptor.MethodDescriptor(
    name='get_mfcc',
    full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferService.get_mfcc',
    index=0,
    containing_service=None,
    input_type=_MFCCBUFFERREQUEST,
    output_type=_MFCCBUFFERRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MFCCBUFFERSERVICE)

DESCRIPTOR.services_by_name['MfccBufferService'] = _MFCCBUFFERSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api.audio.detect import detect_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_detect_dot_detect__pb2
from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


class DetectServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.PersistBlob = channel.unary_unary(
        '/ai.cogneed.api.audio.detect.DetectService/PersistBlob',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_detect_dot_detect__pb2.AudioBlob.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.CreateDetection = channel.unary_unary(
        '/ai.cogneed.api.audio.detect.DetectService/CreateDetection',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_detect_dot_detect__pb2.Detection.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )


class DetectServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def PersistBlob(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateDetection(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DetectServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'PersistBlob': grpc.unary_unary_rpc_method_handler(
          servicer.PersistBlob,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_detect_dot_detect__pb2.AudioBlob.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'CreateDetection': grpc.unary_unary_rpc_method_handler(
          servicer.CreateDetection,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_detect_dot_detect__pb2.Detection.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.audio.detect.DetectService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2
from cogneed_protos.ai.cogneed.api.modelconfig import model_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2


class ModelServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Create = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/Create',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.CreateRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.List = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/List',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ListRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ListResponse.FromString,
        )
    self.Read = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/Read',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.Model.FromString,
        )
    self.Upgrade = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/Upgrade',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
        )
    self.StartTraining = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/StartTraining',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.Deploy = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/Deploy',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.MarkAsTrained = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/MarkAsTrained',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )


class ModelServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Create(self, request, context):
    """Create a new model
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """List all models from a given algorithm
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Read(self, request, context):
    """Fetch data from a given model
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Upgrade(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StartTraining(self, request, context):
    """Start training the given model
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Deploy(self, request, context):
    """Use this model in prod
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MarkAsTrained(self, request, context):
    """Mark the given model as trained
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ModelServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.CreateRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ListRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ListResponse.SerializeToString,
      ),
      'Read': grpc.unary_unary_rpc_method_handler(
          servicer.Read,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.Model.SerializeToString,
      ),
      'Upgrade': grpc.unary_unary_rpc_method_handler(
          servicer.Upgrade,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
      ),
      'StartTraining': grpc.unary_unary_rpc_method_handler(
          servicer.StartTraining,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'Deploy': grpc.unary_unary_rpc_method_handler(
          servicer.Deploy,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'MarkAsTrained': grpc.unary_unary_rpc_method_handler(
          servicer.MarkAsTrained,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.modelconfig.model.ModelService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api.audio import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2
from cogneed_protos.ai.cogneed.api.audio.stream import audio_stream_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_stream_dot_audio__stream__pb2
from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


class StreamAudioServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.InitSession = channel.unary_unary(
        '/ai.cogneed.api.audio.stream.StreamAudioService/InitSession',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2.UserInfo.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_stream_dot_audio__stream__pb2.InitSessionResponse.FromString,
        )
    self.SendAudio = channel.unary_unary(
        '/ai.cogneed.api.audio.stream.StreamAudioService/SendAudio',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_stream_dot_audio__stream__pb2.SendAudioRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2.OptionalDetectionResponse.FromString,
        )
    self.EndSession = channel.unary_unary(
        '/ai.cogneed.api.audio.stream.StreamAudioService/EndSession',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_stream_dot_audio__stream__pb2.EndSessionRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )


class StreamAudioServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def InitSession(self, request, context):
    """Create a new session.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SendAudio(self, request, context):
    """Send an audio blob to check if it contain a keyword.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EndSession(self, request, context):
    """Kill the session with the given uuid.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_StreamAudioServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'InitSession': grpc.unary_unary_rpc_method_handler(
          servicer.InitSession,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2.UserInfo.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_stream_dot_audio__stream__pb2.InitSessionResponse.SerializeToString,
      ),
      'SendAudio': grpc.unary_unary_rpc_method_handler(
          servicer.SendAudio,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_stream_dot_audio__stream__pb2.SendAudioRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2.OptionalDetectionResponse.SerializeToString,
      ),
      'EndSession': grpc.unary_unary_rpc_method_handler(
          servicer.EndSession,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_stream_dot_audio__stream__pb2.EndSessionRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.audio.stream.StreamAudioService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/trainui/record.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/trainui/record.proto',
  package='ai.cogneed.api.trainui.record',
  syntax='proto3',
  serialized_options=_b('\n\035ai.cogneed.api.trainui.recordP\001'),
  serialized_pb=_b('\n2cogneed-protos/ai/cogneed/api/trainui/record.proto\x12\x1d\x61i.cogneed.api.trainui.record\x1a*cogneed-protos/ai/cogneed/api/common.proto\"p\n\x06\x43reate\x12\x15\n\rsentence_uuid\x18\x01 \x01(\t\x12\x13\n\x0bsample_rate\x18\x02 \x01(\x05\x12\x14\n\x0cnum_channels\x18\x03 \x01(\x05\x12\x13\n\x0bsample_size\x18\x04 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\"!\n\nRecordUuid\x12\x13\n\x0brecord_uuid\x18\x01 \x01(\t\"\x1e\n\x0bRecordAudio\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\xec\x01\n\x06Record\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x15\n\rsentence_uuid\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x04 \x01(\x05\x12\x10\n\x08start_ms\x18\x05 \x01(\x05\x12\x0e\n\x06\x65nd_ms\x18\x06 \x01(\x05\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x12\x12\n\nupdated_by\x18\x08 \x01(\t\x12\x12\n\ncreated_at\x18\t \x01(\x03\x12\x12\n\nupdated_at\x18\n \x01(\x03\x12\x39\n\x05state\x18\x0b \x01(\x0e\x32*.ai.cogneed.api.trainui.record.RecordState\"]\n\x0e\x45nhancedRecord\x12\x35\n\x06record\x18\x01 \x01(\x0b\x32%.ai.cogneed.api.trainui.record.Record\x12\x14\n\x0ckeyword_name\x18\x02 \x01(\t\"H\n\x16\x45xtractValidateRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x10\n\x08start_ms\x18\x02 \x01(\x05\x12\x0e\n\x06\x65nd_ms\x18\x03 \x01(\x05\"n\n\x0bListRecords\x12:\n\x06states\x18\x01 \x03(\x0e\x32*.ai.cogneed.api.trainui.record.RecordState\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x15\n\rrows_per_page\x18\x03 \x01(\x05\"d\n\x13ListRecordsResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12>\n\x07records\x18\x02 \x03(\x0b\x32-.ai.cogneed.api.trainui.record.EnhancedRecord*5\n\x0bRecordState\x12\x08\n\x04INIT\x10\x00\x12\r\n\tEXTRACTED\x10\x01\x12\r\n\tVALIDATED\x10\x02\x32\xbd\x04\n\rRecordService\x12L\n\x06\x63reate\x12%.ai.cogneed.api.trainui.record.Create\x1a\x1b.ai.cogneed.api.AckResponse\x12\x63\n\nread_audio\x12).ai.cogneed.api.trainui.record.RecordUuid\x1a*.ai.cogneed.api.trainui.record.RecordAudio\x12X\n\x04read\x12).ai.cogneed.api.trainui.record.RecordUuid\x1a%.ai.cogneed.api.trainui.record.Record\x12\x66\n\x04list\x12*.ai.cogneed.api.trainui.record.ListRecords\x1a\x32.ai.cogneed.api.trainui.record.ListRecordsResponse\x12P\n\x06\x64\x65lete\x12).ai.cogneed.api.trainui.record.RecordUuid\x1a\x1b.ai.cogneed.api.AckResponse\x12\x65\n\x0f\x45xtractValidate\x12\x35.ai.cogneed.api.trainui.record.ExtractValidateRequest\x1a\x1b.ai.cogneed.api.AckResponseB!\n\x1d\x61i.cogneed.api.trainui.recordP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])

_RECORDSTATE = _descriptor.EnumDescriptor(
  name='RecordState',
  full_name='ai.cogneed.api.trainui.record.RecordState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INIT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTRACTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALIDATED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=932,
  serialized_end=985,
)
_sym_db.RegisterEnumDescriptor(_RECORDSTATE)

RecordState = enum_type_wrapper.EnumTypeWrapper(_RECORDSTATE)
INIT = 0
EXTRACTED = 1
VALIDATED = 2



_CREATE = _descriptor.Descriptor(
  name='Create',
  full_name='ai.cogneed.api.trainui.record.Create',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sentence_uuid', full_name='ai.cogneed.api.trainui.record.Create.sentence_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='ai.cogneed.api.trainui.record.Create.sample_rate', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_channels', full_name='ai.cogneed.api.trainui.record.Create.num_channels', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_size', full_name='ai.cogneed.api.trainui.record.Create.sample_size', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.trainui.record.Create.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=241,
)


_RECORDUUID = _descriptor.Descriptor(
  name='RecordUuid',
  full_name='ai.cogneed.api.trainui.record.RecordUuid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='record_uuid', full_name='ai.cogneed.api.trainui.record.RecordUuid.record_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=276,
)


_RECORDAUDIO = _descriptor.Descriptor(
  name='RecordAudio',
  full_name='ai.cogneed.api.trainui.record.RecordAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.trainui.record.RecordAudio.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=308,
)


_RECORD = _descriptor.Descriptor(
  name='Record',
  full_name='ai.cogneed.api.trainui.record.Record',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.trainui.record.Record.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sentence_uuid', full_name='ai.cogneed.api.trainui.record.Record.sentence_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='ai.cogneed.api.trainui.record.Record.duration', index=2,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_ms', full_name='ai.cogneed.api.trainui.record.Record.start_ms', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_ms', full_name='ai.cogneed.api.trainui.record.Record.end_ms', index=4,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='ai.cogneed.api.trainui.record.Record.created_by', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_by', full_name='ai.cogneed.api.trainui.record.Record.updated_by', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='ai.cogneed.api.trainui.record.Record.created_at', index=7,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='ai.cogneed.api.trainui.record.Record.updated_at', index=8,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='ai.cogneed.api.trainui.record.Record.state', index=9,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=547,
)


_ENHANCEDRECORD = _descriptor.Descriptor(
  name='EnhancedRecord',
  full_name='ai.cogneed.api.trainui.record.EnhancedRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='record', full_name='ai.cogneed.api.trainui.record.EnhancedRecord.record', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_name', full_name='ai.cogneed.api.trainui.record.EnhancedRecord.keyword_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=549,
  serialized_end=642,
)


_EXTRACTVALIDATEREQUEST = _descriptor.Descriptor(
  name='ExtractValidateRequest',
  full_name='ai.cogneed.api.trainui.record.ExtractValidateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.trainui.record.ExtractValidateRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_ms', full_name='ai.cogneed.api.trainui.record.ExtractValidateRequest.start_ms', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_ms', full_name='ai.cogneed.api.trainui.record.ExtractValidateRequest.end_ms', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=644,
  serialized_end=716,
)


_LISTRECORDS = _descriptor.Descriptor(
  name='ListRecords',
  full_name='ai.cogneed.api.trainui.record.ListRecords',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='states', full_name='ai.cogneed.api.trainui.record.ListRecords.states', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='ai.cogneed.api.trainui.record.ListRecords.page', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rows_per_page', full_name='ai.cogneed.api.trainui.record.ListRecords.rows_per_page', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=718,
  serialized_end=828,
)


_LISTRECORDSRESPONSE = _descriptor.Descriptor(
  name='ListRecordsResponse',
  full_name='ai.cogneed.api.trainui.record.ListRecordsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='ai.cogneed.api.trainui.record.ListRecordsResponse.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='records', full_name='ai.cogneed.api.trainui.record.ListRecordsResponse.records', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=830,
  serialized_end=930,
)

_RECORD.fields_by_name['state'].enum_type = _RECORDSTATE
_ENHANCEDRECORD.fields_by_name['record'].message_type = _RECORD
_LISTRECORDS.fields_by_name['states'].enum_type = _RECORDSTATE
_LISTRECORDSRESPONSE.fields_by_name['records'].message_type = _ENHANCEDRECORD
DESCRIPTOR.message_types_by_name['Create'] = _CREATE
DESCRIPTOR.message_types_by_name['RecordUuid'] = _RECORDUUID
DESCRIPTOR.message_types_by_name['RecordAudio'] = _RECORDAUDIO
DESCRIPTOR.message_types_by_name['Record'] = _RECORD
DESCRIPTOR.message_types_by_name['EnhancedRecord'] = _ENHANCEDRECORD
DESCRIPTOR.message_types_by_name['ExtractValidateRequest'] = _EXTRACTVALIDATEREQUEST
DESCRIPTOR.message_types_by_name['ListRecords'] = _LISTRECORDS
DESCRIPTOR.message_types_by_name['ListRecordsResponse'] = _LISTRECORDSRESPONSE
DESCRIPTOR.enum_types_by_name['RecordState'] = _RECORDSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Create = _reflection.GeneratedProtocolMessageType('Create', (_message.Message,), dict(
  DESCRIPTOR = _CREATE,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.Create)
  ))
_sym_db.RegisterMessage(Create)

RecordUuid = _reflection.GeneratedProtocolMessageType('RecordUuid', (_message.Message,), dict(
  DESCRIPTOR = _RECORDUUID,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.RecordUuid)
  ))
_sym_db.RegisterMessage(RecordUuid)

RecordAudio = _reflection.GeneratedProtocolMessageType('RecordAudio', (_message.Message,), dict(
  DESCRIPTOR = _RECORDAUDIO,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.RecordAudio)
  ))
_sym_db.RegisterMessage(RecordAudio)

Record = _reflection.GeneratedProtocolMessageType('Record', (_message.Message,), dict(
  DESCRIPTOR = _RECORD,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.Record)
  ))
_sym_db.RegisterMessage(Record)

EnhancedRecord = _reflection.GeneratedProtocolMessageType('EnhancedRecord', (_message.Message,), dict(
  DESCRIPTOR = _ENHANCEDRECORD,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.EnhancedRecord)
  ))
_sym_db.RegisterMessage(EnhancedRecord)

ExtractValidateRequest = _reflection.GeneratedProtocolMessageType('ExtractValidateRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXTRACTVALIDATEREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.ExtractValidateRequest)
  ))
_sym_db.RegisterMessage(ExtractValidateRequest)

ListRecords = _reflection.GeneratedProtocolMessageType('ListRecords', (_message.Message,), dict(
  DESCRIPTOR = _LISTRECORDS,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.ListRecords)
  ))
_sym_db.RegisterMessage(ListRecords)

ListRecordsResponse = _reflection.GeneratedProtocolMessageType('ListRecordsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTRECORDSRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.ListRecordsResponse)
  ))
_sym_db.RegisterMessage(ListRecordsResponse)


DESCRIPTOR._options = None

_RECORDSERVICE = _descriptor.ServiceDescriptor(
  name='RecordService',
  full_name='ai.cogneed.api.trainui.record.RecordService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=988,
  serialized_end=1561,
  methods=[
  _descriptor.MethodDescriptor(
    name='create',
    full_name='ai.cogneed.api.trainui.record.RecordService.create',
    index=0,
    containing_service=None,
    input_type=_CREATE,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='read_audio',
    full_name='ai.cogneed.api.trainui.record.RecordService.read_audio',
    index=1,
    containing_service=None,
    input_type=_RECORDUUID,
    output_type=_RECORDAUDIO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='read',
    full_name='ai.cogneed.api.trainui.record.RecordService.read',
    index=2,
    containing_service=None,
    input_type=_RECORDUUID,
    output_type=_RECORD,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='list',
    full_name='ai.cogneed.api.trainui.record.RecordService.list',
    index=3,
    containing_service=None,
    input_type=_LISTRECORDS,
    output_type=_LISTRECORDSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='delete',
    full_name='ai.cogneed.api.trainui.record.RecordService.delete',
    index=4,
    containing_service=None,
    input_type=_RECORDUUID,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ExtractValidate',
    full_name='ai.cogneed.api.trainui.record.RecordService.ExtractValidate',
    index=5,
    containing_service=None,
    input_type=_EXTRACTVALIDATEREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_RECORDSERVICE)

DESCRIPTOR.services_by_name['RecordService'] = _RECORDSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api.predict.labelmapper import labelmapper_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_labelmapper_dot_labelmapper__pb2


class LabelMapperServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Convert = channel.unary_unary(
        '/ai.cogneed.api.predict.labelmapper.LabelMapperService/Convert',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_labelmapper_dot_labelmapper__pb2.ConvertRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_labelmapper_dot_labelmapper__pb2.ConvertResponse.FromString,
        )


class LabelMapperServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Convert(self, request, context):
    """Retrieve the associate label to the given prediction index.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_LabelMapperServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Convert': grpc.unary_unary_rpc_method_handler(
          servicer.Convert,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_labelmapper_dot_labelmapper__pb2.ConvertRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_labelmapper_dot_labelmapper__pb2.ConvertResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.predict.labelmapper.LabelMapperService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/audio/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/audio/common.proto',
  package='ai.cogneed.api.audio',
  syntax='proto3',
  serialized_options=_b('\n\024ai.cogneed.api.audioP\001'),
  serialized_pb=_b('\n0cogneed-protos/ai/cogneed/api/audio/common.proto\x12\x14\x61i.cogneed.api.audio\"\xa8\x01\n\x0b\x41udioFormat\x12+\n\x03\x65xt\x18\x01 \x01(\x0e\x32\x1e.ai.cogneed.api.audio.AudioExt\x12/\n\x05\x63odec\x18\x02 \x01(\x0e\x32 .ai.cogneed.api.audio.AudioCodec\x12\x13\n\x0bsample_rate\x18\x03 \x01(\x03\x12\x10\n\x08\x63hannels\x18\x04 \x01(\x05\x12\x14\n\x0csample_width\x18\x05 \x01(\x05\"9\n\x11\x44\x65tectionResponse\x12\x13\n\x0bmillisecond\x18\x01 \x01(\x03\x12\x0f\n\x07keyword\x18\x02 \x01(\t\"W\n\x19OptionalDetectionResponse\x12:\n\tdetection\x18\x01 \x01(\x0b\x32\'.ai.cogneed.api.audio.DetectionResponse\"\x1c\n\tAudioBlob\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"(\n\x08UserInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t*8\n\x08\x41udioExt\x12\x08\n\x04WEBM\x10\x00\x12\x07\n\x03MP3\x10\x01\x12\x07\n\x03WAV\x10\x02\x12\x07\n\x03OGG\x10\x03\x12\x07\n\x03RAW\x10\x04*g\n\nAudioCodec\x12\x08\n\x04OPUS\x10\x00\x12\n\n\x06VORBIS\x10\x01\x12\x0e\n\nSIGNED_PCM\x10\x02\x12\x10\n\x0cUNSIGNED_PCM\x10\x03\x12\r\n\tFLOAT_PCM\x10\x04\x12\x08\n\x04ULAW\x10\x05\x12\x08\n\x04\x41LAW\x10\x06*Z\n\x11PersistenceConfig\x12\x15\n\x11RECORD_FULL_AUDIO\x10\x00\x12\x1a\n\x16RECORD_DETECTION_BLOBS\x10\x01\x12\x12\n\x0eRECORD_NOTHING\x10\x02\x42\x18\n\x14\x61i.cogneed.api.audioP\x01\x62\x06proto3')
)

_AUDIOEXT = _descriptor.EnumDescriptor(
  name='AudioExt',
  full_name='ai.cogneed.api.audio.AudioExt',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WEBM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MP3', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAV', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OGG', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAW', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=465,
  serialized_end=521,
)
_sym_db.RegisterEnumDescriptor(_AUDIOEXT)

AudioExt = enum_type_wrapper.EnumTypeWrapper(_AUDIOEXT)
_AUDIOCODEC = _descriptor.EnumDescriptor(
  name='AudioCodec',
  full_name='ai.cogneed.api.audio.AudioCodec',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OPUS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VORBIS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGNED_PCM', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSIGNED_PCM', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOAT_PCM', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ULAW', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALAW', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=523,
  serialized_end=626,
)
_sym_db.RegisterEnumDescriptor(_AUDIOCODEC)

AudioCodec = enum_type_wrapper.EnumTypeWrapper(_AUDIOCODEC)
_PERSISTENCECONFIG = _descriptor.EnumDescriptor(
  name='PersistenceConfig',
  full_name='ai.cogneed.api.audio.PersistenceConfig',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RECORD_FULL_AUDIO', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECORD_DETECTION_BLOBS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECORD_NOTHING', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=628,
  serialized_end=718,
)
_sym_db.RegisterEnumDescriptor(_PERSISTENCECONFIG)

PersistenceConfig = enum_type_wrapper.EnumTypeWrapper(_PERSISTENCECONFIG)
WEBM = 0
MP3 = 1
WAV = 2
OGG = 3
RAW = 4
OPUS = 0
VORBIS = 1
SIGNED_PCM = 2
UNSIGNED_PCM = 3
FLOAT_PCM = 4
ULAW = 5
ALAW = 6
RECORD_FULL_AUDIO = 0
RECORD_DETECTION_BLOBS = 1
RECORD_NOTHING = 2



_AUDIOFORMAT = _descriptor.Descriptor(
  name='AudioFormat',
  full_name='ai.cogneed.api.audio.AudioFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ext', full_name='ai.cogneed.api.audio.AudioFormat.ext', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='codec', full_name='ai.cogneed.api.audio.AudioFormat.codec', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='ai.cogneed.api.audio.AudioFormat.sample_rate', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channels', full_name='ai.cogneed.api.audio.AudioFormat.channels', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_width', full_name='ai.cogneed.api.audio.AudioFormat.sample_width', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=243,
)


_DETECTIONRESPONSE = _descriptor.Descriptor(
  name='DetectionResponse',
  full_name='ai.cogneed.api.audio.DetectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='millisecond', full_name='ai.cogneed.api.audio.DetectionResponse.millisecond', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.api.audio.DetectionResponse.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=302,
)


_OPTIONALDETECTIONRESPONSE = _descriptor.Descriptor(
  name='OptionalDetectionResponse',
  full_name='ai.cogneed.api.audio.OptionalDetectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection', full_name='ai.cogneed.api.audio.OptionalDetectionResponse.detection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=391,
)


_AUDIOBLOB = _descriptor.Descriptor(
  name='AudioBlob',
  full_name='ai.cogneed.api.audio.AudioBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.audio.AudioBlob.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=421,
)


_USERINFO = _descriptor.Descriptor(
  name='UserInfo',
  full_name='ai.cogneed.api.audio.UserInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.cogneed.api.audio.UserInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.audio.UserInfo.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=463,
)

_AUDIOFORMAT.fields_by_name['ext'].enum_type = _AUDIOEXT
_AUDIOFORMAT.fields_by_name['codec'].enum_type = _AUDIOCODEC
_OPTIONALDETECTIONRESPONSE.fields_by_name['detection'].message_type = _DETECTIONRESPONSE
DESCRIPTOR.message_types_by_name['AudioFormat'] = _AUDIOFORMAT
DESCRIPTOR.message_types_by_name['DetectionResponse'] = _DETECTIONRESPONSE
DESCRIPTOR.message_types_by_name['OptionalDetectionResponse'] = _OPTIONALDETECTIONRESPONSE
DESCRIPTOR.message_types_by_name['AudioBlob'] = _AUDIOBLOB
DESCRIPTOR.message_types_by_name['UserInfo'] = _USERINFO
DESCRIPTOR.enum_types_by_name['AudioExt'] = _AUDIOEXT
DESCRIPTOR.enum_types_by_name['AudioCodec'] = _AUDIOCODEC
DESCRIPTOR.enum_types_by_name['PersistenceConfig'] = _PERSISTENCECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AudioFormat = _reflection.GeneratedProtocolMessageType('AudioFormat', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOFORMAT,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.AudioFormat)
  ))
_sym_db.RegisterMessage(AudioFormat)

DetectionResponse = _reflection.GeneratedProtocolMessageType('DetectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _DETECTIONRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.DetectionResponse)
  ))
_sym_db.RegisterMessage(DetectionResponse)

OptionalDetectionResponse = _reflection.GeneratedProtocolMessageType('OptionalDetectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _OPTIONALDETECTIONRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.OptionalDetectionResponse)
  ))
_sym_db.RegisterMessage(OptionalDetectionResponse)

AudioBlob = _reflection.GeneratedProtocolMessageType('AudioBlob', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOBLOB,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.AudioBlob)
  ))
_sym_db.RegisterMessage(AudioBlob)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERINFO,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.UserInfo)
  ))
_sym_db.RegisterMessage(UserInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/audio/stream/audio_stream.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2
from cogneed_protos.ai.cogneed.api.audio import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/audio/stream/audio_stream.proto',
  package='ai.cogneed.api.audio.stream',
  syntax='proto3',
  serialized_options=_b('\n\033ai.cogneed.api.audio.streamP\001'),
  serialized_pb=_b('\n=cogneed-protos/ai/cogneed/api/audio/stream/audio_stream.proto\x12\x1b\x61i.cogneed.api.audio.stream\x1a*cogneed-protos/ai/cogneed/api/common.proto\x1a\x30\x63ogneed-protos/ai/cogneed/api/audio/common.proto\"7\n\x13InitSessionResponse\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\r\n\x05major\x18\x02 \x01(\t\",\n\tModelInfo\x12\r\n\x05major\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t\"\x94\x02\n\x10SendAudioRequest\x12\x37\n\x0c\x61udio_format\x18\x01 \x01(\x0b\x32!.ai.cogneed.api.audio.AudioFormat\x12\x43\n\x12persistence_config\x18\x02 \x01(\x0e\x32\'.ai.cogneed.api.audio.PersistenceConfig\x12:\n\nmodel_info\x18\x03 \x01(\x0b\x32&.ai.cogneed.api.audio.stream.ModelInfo\x12\x11\n\tcall_uuid\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\x12\x12\n\nblob_index\x18\x06 \x01(\x03\x12\x0e\n\x06millis\x18\x07 \x01(\x03\"&\n\x11\x45ndSessionRequest\x12\x11\n\tcall_uuid\x18\x01 \x01(\t2\xbd\x02\n\x12StreamAudioService\x12_\n\x0bInitSession\x12\x1e.ai.cogneed.api.audio.UserInfo\x1a\x30.ai.cogneed.api.audio.stream.InitSessionResponse\x12k\n\tSendAudio\x12-.ai.cogneed.api.audio.stream.SendAudioRequest\x1a/.ai.cogneed.api.audio.OptionalDetectionResponse\x12Y\n\nEndSession\x12..ai.cogneed.api.audio.stream.EndSessionRequest\x1a\x1b.ai.cogneed.api.AckResponseB\x1f\n\x1b\x61i.cogneed.api.audio.streamP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2.DESCRIPTOR,])




_INITSESSIONRESPONSE = _descriptor.Descriptor(
  name='InitSessionResponse',
  full_name='ai.cogneed.api.audio.stream.InitSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.stream.InitSessionResponse.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.audio.stream.InitSessionResponse.major', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=243,
)


_MODELINFO = _descriptor.Descriptor(
  name='ModelInfo',
  full_name='ai.cogneed.api.audio.stream.ModelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.audio.stream.ModelInfo.major', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.audio.stream.ModelInfo.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=289,
)


_SENDAUDIOREQUEST = _descriptor.Descriptor(
  name='SendAudioRequest',
  full_name='ai.cogneed.api.audio.stream.SendAudioRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_format', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.audio_format', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistence_config', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.persistence_config', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_info', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.model_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.call_uuid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.blob_index', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='millis', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.millis', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=568,
)


_ENDSESSIONREQUEST = _descriptor.Descriptor(
  name='EndSessionRequest',
  full_name='ai.cogneed.api.audio.stream.EndSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.stream.EndSessionRequest.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=608,
)

_SENDAUDIOREQUEST.fields_by_name['audio_format'].message_type = cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2._AUDIOFORMAT
_SENDAUDIOREQUEST.fields_by_name['persistence_config'].enum_type = cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2._PERSISTENCECONFIG
_SENDAUDIOREQUEST.fields_by_name['model_info'].message_type = _MODELINFO
DESCRIPTOR.message_types_by_name['InitSessionResponse'] = _INITSESSIONRESPONSE
DESCRIPTOR.message_types_by_name['ModelInfo'] = _MODELINFO
DESCRIPTOR.message_types_by_name['SendAudioRequest'] = _SENDAUDIOREQUEST
DESCRIPTOR.message_types_by_name['EndSessionRequest'] = _ENDSESSIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InitSessionResponse = _reflection.GeneratedProtocolMessageType('InitSessionResponse', (_message.Message,), dict(
  DESCRIPTOR = _INITSESSIONRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.stream.audio_stream_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.stream.InitSessionResponse)
  ))
_sym_db.RegisterMessage(InitSessionResponse)

ModelInfo = _reflection.GeneratedProtocolMessageType('ModelInfo', (_message.Message,), dict(
  DESCRIPTOR = _MODELINFO,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.stream.audio_stream_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.stream.ModelInfo)
  ))
_sym_db.RegisterMessage(ModelInfo)

SendAudioRequest = _reflection.GeneratedProtocolMessageType('SendAudioRequest', (_message.Message,), dict(
  DESCRIPTOR = _SENDAUDIOREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.stream.audio_stream_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.stream.SendAudioRequest)
  ))
_sym_db.RegisterMessage(SendAudioRequest)

EndSessionRequest = _reflection.GeneratedProtocolMessageType('EndSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENDSESSIONREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.stream.audio_stream_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.stream.EndSessionRequest)
  ))
_sym_db.RegisterMessage(EndSessionRequest)


DESCRIPTOR._options = None

_STREAMAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='StreamAudioService',
  full_name='ai.cogneed.api.audio.stream.StreamAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=611,
  serialized_end=928,
  methods=[
  _descriptor.MethodDescriptor(
    name='InitSession',
    full_name='ai.cogneed.api.audio.stream.StreamAudioService.InitSession',
    index=0,
    containing_service=None,
    input_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2._USERINFO,
    output_type=_INITSESSIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SendAudio',
    full_name='ai.cogneed.api.audio.stream.StreamAudioService.SendAudio',
    index=1,
    containing_service=None,
    input_type=_SENDAUDIOREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2._OPTIONALDETECTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EndSession',
    full_name='ai.cogneed.api.audio.stream.StreamAudioService.EndSession',
    index=2,
    containing_service=None,
    input_type=_ENDSESSIONREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMAUDIOSERVICE)

DESCRIPTOR.services_by_name['StreamAudioService'] = _STREAMAUDIOSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/common.proto',
  package='ai.cogneed.api',
  syntax='proto3',
  serialized_options=_b('\n\016ai.cogneed.apiP\001'),
  serialized_pb=_b('\n*cogneed-protos/ai/cogneed/api/common.proto\x12\x0e\x61i.cogneed.api\"\r\n\x0b\x41\x63kResponseB\x12\n\x0e\x61i.cogneed.apiP\x01\x62\x06proto3')
)




_ACKRESPONSE = _descriptor.Descriptor(
  name='AckResponse',
  full_name='ai.cogneed.api.AckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=75,
)

DESCRIPTOR.message_types_by_name['AckResponse'] = _ACKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AckResponse = _reflection.GeneratedProtocolMessageType('AckResponse', (_message.Message,), dict(
  DESCRIPTOR = _ACKRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.AckResponse)
  ))
_sym_db.RegisterMessage(AckResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/audio/detect/detect.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/audio/detect/detect.proto',
  package='ai.cogneed.api.audio.detect',
  syntax='proto3',
  serialized_options=_b('\n\033ai.cogneed.api.audio.detectP\001'),
  serialized_pb=_b('\n7cogneed-protos/ai/cogneed/api/audio/detect/detect.proto\x12\x1b\x61i.cogneed.api.audio.detect\x1a*cogneed-protos/ai/cogneed/api/common.proto\"C\n\tAudioBlob\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x12\n\nblob_index\x18\x03 \x01(\x03\"\x82\x01\n\tDetection\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x11\n\tcall_uuid\x18\x02 \x01(\t\x12\x15\n\ruse_case_uuid\x18\x03 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x04 \x01(\t\x12\x12\n\nblob_index\x18\t \x01(\x05\x12\x13\n\x0bwindow_size\x18\n \x01(\x05\x32\xbb\x01\n\rDetectService\x12R\n\x0bPersistBlob\x12&.ai.cogneed.api.audio.detect.AudioBlob\x1a\x1b.ai.cogneed.api.AckResponse\x12V\n\x0f\x43reateDetection\x12&.ai.cogneed.api.audio.detect.Detection\x1a\x1b.ai.cogneed.api.AckResponseB\x1f\n\x1b\x61i.cogneed.api.audio.detectP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])




_AUDIOBLOB = _descriptor.Descriptor(
  name='AudioBlob',
  full_name='ai.cogneed.api.audio.detect.AudioBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.detect.AudioBlob.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.audio.detect.AudioBlob.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.audio.detect.AudioBlob.blob_index', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=199,
)


_DETECTION = _descriptor.Descriptor(
  name='Detection',
  full_name='ai.cogneed.api.audio.detect.Detection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.audio.detect.Detection.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.detect.Detection.call_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case_uuid', full_name='ai.cogneed.api.audio.detect.Detection.use_case_uuid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.audio.detect.Detection.keyword_uuid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.audio.detect.Detection.blob_index', index=4,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='window_size', full_name='ai.cogneed.api.audio.detect.Detection.window_size', index=5,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=332,
)

DESCRIPTOR.message_types_by_name['AudioBlob'] = _AUDIOBLOB
DESCRIPTOR.message_types_by_name['Detection'] = _DETECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AudioBlob = _reflection.GeneratedProtocolMessageType('AudioBlob', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOBLOB,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.detect.detect_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.detect.AudioBlob)
  ))
_sym_db.RegisterMessage(AudioBlob)

Detection = _reflection.GeneratedProtocolMessageType('Detection', (_message.Message,), dict(
  DESCRIPTOR = _DETECTION,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.detect.detect_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.detect.Detection)
  ))
_sym_db.RegisterMessage(Detection)


DESCRIPTOR._options = None

_DETECTSERVICE = _descriptor.ServiceDescriptor(
  name='DetectService',
  full_name='ai.cogneed.api.audio.detect.DetectService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=335,
  serialized_end=522,
  methods=[
  _descriptor.MethodDescriptor(
    name='PersistBlob',
    full_name='ai.cogneed.api.audio.detect.DetectService.PersistBlob',
    index=0,
    containing_service=None,
    input_type=_AUDIOBLOB,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDetection',
    full_name='ai.cogneed.api.audio.detect.DetectService.CreateDetection',
    index=1,
    containing_service=None,
    input_type=_DETECTION,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DETECTSERVICE)

DESCRIPTOR.services_by_name['DetectService'] = _DETECTSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/audio/recorder/recorder.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/audio/recorder/recorder.proto',
  package='ai.cogneed.api.audio.recorder',
  syntax='proto3',
  serialized_options=_b('\n\035ai.cogneed.api.audio.recorderP\001'),
  serialized_pb=_b('\n;cogneed-protos/ai/cogneed/api/audio/recorder/recorder.proto\x12\x1d\x61i.cogneed.api.audio.recorder\x1a*cogneed-protos/ai/cogneed/api/common.proto\"B\n\rRecordRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x12\n\nblob_index\x18\x03 \x01(\x03\"\"\n\x12\x43onsolidateRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t2\xc3\x01\n\rRecordService\x12S\n\x06Record\x12,.ai.cogneed.api.audio.recorder.RecordRequest\x1a\x1b.ai.cogneed.api.AckResponse\x12]\n\x0b\x43onsolidate\x12\x31.ai.cogneed.api.audio.recorder.ConsolidateRequest\x1a\x1b.ai.cogneed.api.AckResponseB!\n\x1d\x61i.cogneed.api.audio.recorderP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])




_RECORDREQUEST = _descriptor.Descriptor(
  name='RecordRequest',
  full_name='ai.cogneed.api.audio.recorder.RecordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.audio.recorder.RecordRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.audio.recorder.RecordRequest.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.audio.recorder.RecordRequest.blob_index', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=204,
)


_CONSOLIDATEREQUEST = _descriptor.Descriptor(
  name='ConsolidateRequest',
  full_name='ai.cogneed.api.audio.recorder.ConsolidateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.audio.recorder.ConsolidateRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=240,
)

DESCRIPTOR.message_types_by_name['RecordRequest'] = _RECORDREQUEST
DESCRIPTOR.message_types_by_name['ConsolidateRequest'] = _CONSOLIDATEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecordRequest = _reflection.GeneratedProtocolMessageType('RecordRequest', (_message.Message,), dict(
  DESCRIPTOR = _RECORDREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.recorder.recorder_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.recorder.RecordRequest)
  ))
_sym_db.RegisterMessage(RecordRequest)

ConsolidateRequest = _reflection.GeneratedProtocolMessageType('ConsolidateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSOLIDATEREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.recorder.recorder_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.recorder.ConsolidateRequest)
  ))
_sym_db.RegisterMessage(ConsolidateRequest)


DESCRIPTOR._options = None

_RECORDSERVICE = _descriptor.ServiceDescriptor(
  name='RecordService',
  full_name='ai.cogneed.api.audio.recorder.RecordService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=243,
  serialized_end=438,
  methods=[
  _descriptor.MethodDescriptor(
    name='Record',
    full_name='ai.cogneed.api.audio.recorder.RecordService.Record',
    index=0,
    containing_service=None,
    input_type=_RECORDREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Consolidate',
    full_name='ai.cogneed.api.audio.recorder.RecordService.Consolidate',
    index=1,
    containing_service=None,
    input_type=_CONSOLIDATEREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_RECORDSERVICE)

DESCRIPTOR.services_by_name['RecordService'] = _RECORDSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/predict/labelmapper/labelmapper.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/predict/labelmapper/labelmapper.proto',
  package='ai.cogneed.api.predict.labelmapper',
  syntax='proto3',
  serialized_options=_b('\n\"ai.cogneed.api.predict.labelmapperP\001'),
  serialized_pb=_b('\nCcogneed-protos/ai/cogneed/api/predict/labelmapper/labelmapper.proto\x12\"ai.cogneed.api.predict.labelmapper\"O\n\x0e\x43onvertRequest\x12\x18\n\x10prediction_index\x18\x01 \x01(\x05\x12\x12\n\nmodel_name\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\x03\"\'\n\x0f\x43onvertResponse\x12\x14\n\x0ckeyword_uuid\x18\x01 \x01(\t2\x88\x01\n\x12LabelMapperService\x12r\n\x07\x43onvert\x12\x32.ai.cogneed.api.predict.labelmapper.ConvertRequest\x1a\x33.ai.cogneed.api.predict.labelmapper.ConvertResponseB&\n\"ai.cogneed.api.predict.labelmapperP\x01\x62\x06proto3')
)




_CONVERTREQUEST = _descriptor.Descriptor(
  name='ConvertRequest',
  full_name='ai.cogneed.api.predict.labelmapper.ConvertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction_index', full_name='ai.cogneed.api.predict.labelmapper.ConvertRequest.prediction_index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_name', full_name='ai.cogneed.api.predict.labelmapper.ConvertRequest.model_name', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='ai.cogneed.api.predict.labelmapper.ConvertRequest.version', index=2,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=186,
)


_CONVERTRESPONSE = _descriptor.Descriptor(
  name='ConvertResponse',
  full_name='ai.cogneed.api.predict.labelmapper.ConvertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.predict.labelmapper.ConvertResponse.keyword_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=227,
)

DESCRIPTOR.message_types_by_name['ConvertRequest'] = _CONVERTREQUEST
DESCRIPTOR.message_types_by_name['ConvertResponse'] = _CONVERTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConvertRequest = _reflection.GeneratedProtocolMessageType('ConvertRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONVERTREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.labelmapper.labelmapper_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.labelmapper.ConvertRequest)
  ))
_sym_db.RegisterMessage(ConvertRequest)

ConvertResponse = _reflection.GeneratedProtocolMessageType('ConvertResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONVERTRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.labelmapper.labelmapper_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.labelmapper.ConvertResponse)
  ))
_sym_db.RegisterMessage(ConvertResponse)


DESCRIPTOR._options = None

_LABELMAPPERSERVICE = _descriptor.ServiceDescriptor(
  name='LabelMapperService',
  full_name='ai.cogneed.api.predict.labelmapper.LabelMapperService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=230,
  serialized_end=366,
  methods=[
  _descriptor.MethodDescriptor(
    name='Convert',
    full_name='ai.cogneed.api.predict.labelmapper.LabelMapperService.Convert',
    index=0,
    containing_service=None,
    input_type=_CONVERTREQUEST,
    output_type=_CONVERTRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_LABELMAPPERSERVICE)

DESCRIPTOR.services_by_name['LabelMapperService'] = _LABELMAPPERSERVICE

# @@protoc_insertion_point(module_scope)
